#!/usr/bin/perl

#Example of how to use the search api to get information from microbedb using an object as the search field
#Searchable objects are:
#GenomeProject, Replicon, Gene, Version, or UpdateLog

#See table_search_example.pl, if you want to do a simple search on a mysql db table that is not part of the microbedb api  


#This script retrieves all chromosome replicons from a single download version,
#Then, each replicon is processed to get the genomeproject annotations associated with it
#Finally, the actual replicon sequence is retrieved

use warnings;
use strict;

use lib "/home/mlangill/common/workspace/microbedb/MicrobeDB/";

#we need to use the Search library (this also imports GenomeProject,Replicon, and Gene libs)
use Search;

#Create an object with certain features that we want
#In this case, we are searching for all chromosomes (i.e. not plasmids) from download version 1
my $rep_obj = new Replicon( version_id => '1', rep_type => 'chromosome' );

#Create the search object.
my $search_obj = new Search();

#do the actual search using the replicon object to set the search parameters
#all objects that match the search criteria are returned as an array of the same type of objects
my @result_objs = $search_obj->object_search($rep_obj);

#iterate through each replicon object that was returned
foreach my $curr_rep_obj (@result_objs) {

	#get the name of the replicon
	my $rep_name = $curr_rep_obj->definition;

	#Get the genome project that is associated with this replicon
	#change the return object type to GenomeProject so that we can search with a Replicon object
	$search_obj->return_obj('GenomeProject');
	my ($curr_gpo) = $search_obj->object_search($curr_rep_obj);

	#Get information about the pathogencity of the organism
	my $patho = $curr_gpo->patho_status;

	print "Replicon Name: $rep_name Patho: $patho \n";


	#get the replicon sequence (replicon sequence is not retrieved by default)

	#First, change the default return_seqs to 1
	$search_obj->return_seqs(1);

	#Second, we want a Replicon object returned
	#Since this was previously set to GenomeProject we must explicitly change it
	$search_obj->return_obj('Replicon');

	#last, do the search and store it back to the same object
	#Note, this retrival/search takes awhile due to the size of the replicon sequence
	($curr_rep_obj) = $search_obj->object_search($curr_rep_obj);

	#store the replicon sequence in another variable
	my $rep_seq = $curr_rep_obj->rep_seq;

#...do something with the replicon sequence before moving on to the next replicon

}

print "All done test!\n";    
